@@ -23,6 +23,10 @@
 
 #include "./gxtuner.h"
 
+#include <gtk/gtkprivate.h>
+#include <string.h> 
+#include <math.h>
+
 #define P_(s) (s)   // FIXME -> gettext
 
 enum {
@@ -41,7 +45,7 @@ static void gx_tuner_get_property(
     GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
 
 static const int tuner_width = 100;
-static const int tuner_height = 70;
+static const int tuner_height = 60;
 static const double rect_width = 100;
 static const double rect_height = 60;
 
@@ -182,7 +186,7 @@ static gboolean gtk_tuner_expose (GtkWidget *widget, GdkEventExpose *event) {
     cairo_t *cr;
 
     double x0      = (widget->allocation.width - 100) * 0.5;
-    double y0      = (widget->allocation.height - 70) * 0.5;
+    double y0      = (widget->allocation.height - 60) * 0.5;
 
     cr = gdk_cairo_create(widget->window);
     cairo_save(cr);
@@ -191,12 +195,12 @@ static gboolean gtk_tuner_expose (GtkWidget *widget, GdkEventExpose *event) {
     static double grow   = 0.;
 
     if(widget->allocation.width > widget->allocation.height +(10.*grow*3)) {
-        grow = (widget->allocation.height/70.)/10.;
+        grow = (widget->allocation.height/60.)/10.;
     } else {
         grow =  (widget->allocation.width/100.)/10.;
     }
     
-    grow_h = (widget->allocation.height/70.)/3.;
+    grow_h = (widget->allocation.height/60.)/3.;
     grow_w =  (widget->allocation.width/100.)/3.;
     
     cairo_translate(cr, -x0*grow_w, -y0*grow_h);
@@ -254,7 +258,7 @@ static gboolean gtk_tuner_expose (GtkWidget *widget, GdkEventExpose *event) {
     }
 
     // display frequency
-    char s[10];
+    char s[12];
     snprintf(s, sizeof(s), "%.0f Hz", tuner->freq);
     cairo_set_source_rgba (cr, 0.8, 0.8, 0.2,0.6);
     cairo_set_font_size (cr, 8.0);
@@ -262,7 +266,22 @@ static gboolean gtk_tuner_expose (GtkWidget *widget, GdkEventExpose *event) {
     cairo_text_extents(cr, s, &ex);
     cairo_move_to (cr, x0+90-ex.width, y0+58);
     cairo_show_text(cr, s);
-
+    // display cent
+    if(scale>-0.5) {
+        if(scale>-0.002)
+            snprintf(s, sizeof(s), "+%.0f cent", (floorf(scale * 10000) / 50));
+        else 
+            snprintf(s, sizeof(s), "%.0f cent", (floorf(scale * 10000) / 50));
+    } else {
+        snprintf(s, sizeof(s), "+ - cent");
+    }    
+    cairo_set_source_rgba (cr, 0.8, 0.8, 0.2,0.6);
+    cairo_set_font_size (cr, 6.0);
+    cairo_text_extents(cr, s, &ex);
+    cairo_move_to (cr, x0+35-ex.width, y0+58);
+    cairo_show_text(cr, s);
+    
+    
     double ux=2., uy=2.;
     cairo_device_to_user_distance (cr, &ux, &uy);
     if (ux < uy)
@@ -275,7 +294,7 @@ static gboolean gtk_tuner_expose (GtkWidget *widget, GdkEventExpose *event) {
     cairo_set_line_join(cr, CAIRO_LINE_JOIN_ROUND);
     cairo_set_line_cap(cr, CAIRO_LINE_CAP_ROUND);
     cairo_set_dash (cr, dash_ind, sizeof(dash_ind)/sizeof(dash_ind[0]), 0);
-    cairo_line_to(cr, (scale*2*rect_width)+x0+47, y0+(scale*scale*30)+2);
+    cairo_line_to(cr, (scale*2*rect_width)+x0+50, y0+(scale*scale*30)+2);
     cairo_set_source_rgb(cr,  0.5, 0.1, 0.1);
     cairo_stroke(cr);   
     cairo_destroy(cr);
@@ -294,21 +313,11 @@ static void draw_background(cairo_surface_t *surface) {
 
     cr = cairo_create(surface);
     cairo_scale(cr, 3, 3);
-    // bottom part of gauge
-    cairo_rectangle (cr, x0,y0+60,rect_width+1,30);
-    cairo_set_source_rgb (cr, 0, 0, 0);
-    cairo_fill(cr);
-    cairo_set_source_rgb(cr,  0.2, 0.2, 0.2);
-    cairo_set_line_width(cr, 5.0);
-    cairo_move_to(cr,x0+2, y0+63);
-    cairo_line_to(cr, x0+99, y0+63);
-    cairo_stroke(cr);
-
-    // upper part
+    // background
     cairo_rectangle (cr, x0-1,y0-1,rect_width+2,rect_height+2);
     cairo_set_source_rgb (cr, 0, 0, 0);
     cairo_fill(cr);
-
+    // light
     cairo_pattern_t*pat =
         cairo_pattern_create_radial (-50, y0, 5,rect_width-10,  rect_height, 20.0);
     cairo_pattern_add_color_stop_rgb (pat, 0, 1, 1, 1);
@@ -318,27 +327,12 @@ static void draw_background(cairo_surface_t *surface) {
     cairo_set_source (cr, pat);
     cairo_rectangle (cr, x0+2,y0+2,rect_width-3,rect_height-3);
     cairo_fill(cr);
-
-    cairo_set_source_rgb(cr,  0.2, 0.2, 0.2);
-    cairo_set_line_width(cr, 2.0);
-    cairo_move_to(cr,x0+98, y0+3);
-    cairo_line_to(cr, x0+98, y0+64);
-    cairo_stroke(cr);
-
-    cairo_set_source_rgb(cr,  0.1, 0.1, 0.1);
-    cairo_set_line_width(cr, 2.0);
-    cairo_move_to(cr,x0+3, y0+64);
-    cairo_line_to(cr, x0+3, y0+3);
-    cairo_line_to(cr, x0+98, y0+3);
-    cairo_stroke(cr);
-
+     // division scale
     pat = cairo_pattern_create_linear (x0+50, y0,x0, y0);
     cairo_pattern_set_extend(pat, CAIRO_EXTEND_REFLECT);
     cairo_pattern_add_color_stop_rgb (pat, 0, 0.1, 0.8, 0.1);
     cairo_pattern_add_color_stop_rgb (pat, 1, 1, 0.1, 0.1);
     cairo_set_source (cr, pat);
-
-    // division scale
     cairo_set_dash (cr, dashes, sizeof (dashes)/sizeof(dashes[0]), 100.0);
     cairo_set_line_width(cr, 3.0);
     for (int i = -5; i < 6; i++) {
@@ -346,185 +340,15 @@ static void draw_background(cairo_surface_t *surface) {
         cairo_line_to(cr, (((i*0.08))*rect_width)+x0+50, y0+(((i*0.1*i*0.1))*30)+2);
     }
     cairo_stroke(cr);
-
-    cairo_set_source_rgb(cr,  0.1, 1, 0.1);
-    cairo_move_to(cr,x0+50, y0+rect_height-5);
-    cairo_line_to(cr, x0+50, y0+2);
-    cairo_stroke(cr);
-
     // indicator shaft (circle)
     cairo_set_dash (cr, dash_ind, sizeof(dash_ind)/sizeof(dash_ind[0]), 0);
-    //cairo_set_dash (cr, 0, 0, 0); // (for full circle)
     cairo_move_to(cr, x0+50, y0+rect_height-5);
     cairo_arc(cr, x0+50, y0+rect_height-5, 2.0, 0, 2*M_PI);
     cairo_set_source_rgb(cr,  0.5, 0.1, 0.1);
     cairo_set_line_width(cr, 2.0);
     cairo_stroke(cr);
     cairo_pattern_destroy (pat);
-
     cairo_destroy(cr);
 }
 
-TunerWidget::TunerWidget() {}
-TunerWidget::~TunerWidget() {}
-
-void TunerWidget::session_quit() {
-    jack_port_unregister(cptr->gc(), cptr->gp());
-    jack_deactivate(cptr->gc());
-    jack_client_close(cptr->gc());
-    if (tw.g_threads > 0) {
-        g_source_remove(tw.g_threads);
-    }
-    gtk_main_quit ();
-}
-
-void TunerWidget::destroy( GtkWidget *widget, gpointer data) {
-    jack_port_unregister(cptr->gc(), cptr->gp());
-    jack_deactivate(cptr->gc());
-    jack_client_close(cptr->gc());
-    if (tw.g_threads > 0) {
-        g_source_remove(tw.g_threads);
-    }
-    gtk_main_quit ();
-}
-
-gboolean TunerWidget::delete_event(GtkWidget *widget, GdkEvent *event,
-                             gpointer data) {
-    return FALSE;
-}
-
-gboolean TunerWidget::gx_update_frequency(gpointer arg) {
-    gx_tuner_set_freq(GX_TUNER(tw.get_tuner()),
-        cptr->ef());
-    return true;
-}
-
-gboolean TunerWidget::ref_freq_changed(gpointer arg) {
-    gx_tuner_set_reference_pitch(GX_TUNER(tw.get_tuner()),
-        gtk_adjustment_get_value(GTK_ADJUSTMENT(arg)));
-    return true;
-}
-
-gboolean TunerWidget::threshold_changed(gpointer arg) {
-    cptr->sf(gtk_adjustment_get_value(GTK_ADJUSTMENT(arg)));
-    return true;
-}
-
-void TunerWidget::signal_handler(int sig) {
-    // print out a warning
-    g_print ("signal: %i received, exiting ...\n", sig);
-    destroy(NULL,NULL);
-}
-
-void TunerWidget::create_window() {
-    // create main window and set icon to use
-    err = NULL;
-    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_icon_from_file(GTK_WINDOW(window),
-        (std::string(PIXMAPS_DIR) + "/gxtuner.png").c_str(),&err);
-    if (err != NULL) g_error_free(err);
-    // create all used widgets
-    tuner = gx_tuner_new();
-    box = gtk_vbox_new(false, 0);
-    hbox = gtk_hbox_new(false, 0);
-    abox = gtk_alignment_new (1.0,1.0,0.0,0.0);
-    bbox = gtk_alignment_new (0.0,0.0,0.0,0.0);
-    adj = gtk_adjustment_new(440, 427, 453, 0.1, 1.0, 0);
-    spinner = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 0.1, 1);
-    adjt = gtk_adjustment_new(0.001, 0.001, 0.5, 0.001, 1.0, 0);
-    spinnert = gtk_spin_button_new(GTK_ADJUSTMENT(adjt), 0.001, 3);
-    // set some options to widgets
-    gtk_widget_set_app_paintable(window, TRUE);
-    gtk_widget_set_redraw_on_allocate(GTK_WIDGET(window), TRUE); 
-    gtk_widget_set_can_focus(GTK_WIDGET(spinner), false);
-    gtk_widget_set_can_focus(GTK_WIDGET(spinnert), false);
-    gtk_widget_set_can_default(GTK_WIDGET(spinner), true);
-    gtk_widget_set_can_default(GTK_WIDGET(spinnert), true);
-    gtk_widget_set_tooltip_text(GTK_WIDGET(spinner),"reference pitch");
-    gtk_widget_set_tooltip_text(GTK_WIDGET(spinnert),"threshold");
-    // set some colour for widgets
-    GdkColor colorOwn;
-    gdk_color_parse("#000000", &colorOwn);
-    gtk_widget_modify_bg(window, GTK_STATE_NORMAL, &colorOwn);
-    gtk_widget_modify_bg(spinner, GTK_STATE_NORMAL, &colorOwn);
-    gtk_widget_modify_bg(spinnert, GTK_STATE_NORMAL, &colorOwn);
-    gtk_widget_modify_base(spinner, GTK_STATE_NORMAL, &colorOwn);
-    gtk_widget_modify_base(spinnert, GTK_STATE_NORMAL, &colorOwn);
-    gdk_color_parse("#292929", &colorOwn);
-    gtk_widget_modify_fg(spinner, GTK_STATE_NORMAL, &colorOwn);
-    gtk_widget_modify_fg(spinnert, GTK_STATE_NORMAL, &colorOwn);
-    gdk_color_parse("#797979", &colorOwn);
-    gtk_widget_modify_fg(spinner, GTK_STATE_PRELIGHT, &colorOwn);
-    gtk_widget_modify_fg(spinnert, GTK_STATE_PRELIGHT, &colorOwn);
-    gdk_color_parse("#999909", &colorOwn);
-    gtk_widget_modify_text(spinner, GTK_STATE_NORMAL, &colorOwn);
-    gtk_widget_modify_text(spinnert, GTK_STATE_NORMAL, &colorOwn);
-    // stack all together
-    gtk_container_add (GTK_CONTAINER(window), box);
-    gtk_box_pack_start(GTK_BOX(box), tuner,true,true,0);
-    gtk_box_pack_end(GTK_BOX(box), hbox, false,false,0);
-    gtk_container_add (GTK_CONTAINER (bbox), spinnert);
-    gtk_box_pack_start(GTK_BOX(hbox),bbox,false,false,0);
-    gtk_box_pack_end(GTK_BOX(hbox),abox,false,false,0);
-    gtk_container_add (GTK_CONTAINER (abox), spinner);
-    // connect the signal handlers 
-    g_signal_connect(GTK_OBJECT(adj), "value-changed",
-        G_CALLBACK(ref_freq_changed),(gpointer)adj);
-    g_signal_connect(GTK_OBJECT(adjt), "value-changed",
-        G_CALLBACK(threshold_changed),(gpointer)adjt);
-    g_signal_connect (window, "delete-event",
-            G_CALLBACK (delete_event), NULL);
-    g_signal_connect (window, "destroy",
-            G_CALLBACK (destroy), NULL);
-}
-
-void TunerWidget::parse_cmd() {
-    // *** commandline parsing ***
-    // set default window size optional by command line options
-    int x = 120;
-    int y = 100;        
-    if (!cptr->cv(1).empty()) {
-        x = atoi(cptr->cv(1).c_str());
-    }
-    if (!cptr->cv(2).empty()) {
-        y = atoi(cptr->cv(2).c_str());
-    }
-    gtk_window_set_default_size(GTK_WINDOW(window), x,y);
-    // set default window position optional by command line options
-    if (!cptr->cv(3).empty()) {
-        x = atoi(cptr->cv(3).c_str());
-    } else {
-        x = gdk_screen_width()/2 -x;
-    }
-    if (!cptr->cv(4).empty()) {
-        y = atoi(cptr->cv(4).c_str());
-    } else {
-        y = gdk_screen_height()/2 -y;
-    }
-    gtk_window_move(GTK_WINDOW(window),x,y);
-    // set reference pitch and threshold by command line options
-    double p,t;
-    if (!cptr->cv(5).empty()) {
-        p = atof(cptr->cv(5).c_str());
-    } else {
-        p = 440.0;
-    }
-    if (!cptr->cv(6).empty()) {
-        t = atof(cptr->cv(6).c_str());
-    } else {
-        t = 0.001;
-    }
-    gtk_adjustment_set_value(GTK_ADJUSTMENT(adj),p);
-    gtk_adjustment_set_value(GTK_ADJUSTMENT(adjt),t);
-}
-
-void TunerWidget::show() {
-   // finaly show the window with all widgets
-    gtk_widget_show_all(window);
-}
-
-TunerWidget tw;
-CmdPtr *cptr = 0;
-
-
 
